@@ -15,6 +15,21 @@ source = openapi.Parameter(
 
 BASE = [projection, source]
 
+fmt_png = openapi.Parameter(
+    'fmt',
+    openapi.IN_PATH,
+    description='Image format (png | jpeg)',
+    type=openapi.TYPE_STRING,
+    default='png',
+)
+fmt_tiff = openapi.Parameter(
+    'fmt',
+    openapi.IN_PATH,
+    description='Image data format (png | jpeg | tiff)',
+    type=openapi.TYPE_STRING,
+    default='tiff',
+)
+
 z = openapi.Parameter(
     'z',
     openapi.IN_PATH,
@@ -100,7 +115,7 @@ units = openapi.Parameter(
     type=openapi.TYPE_STRING,
 )
 
-REGION = [left, right, top, bottom, units]
+REGION = [left, right, top, bottom, units, fmt_tiff]
 
 # Histogram Parameters
 only = openapi.Parameter(
@@ -146,4 +161,4 @@ max_height = openapi.Parameter(
     default=256,
 )
 
-THUMBNAIL = [max_height, max_width]
+THUMBNAIL = [fmt_png, max_height, max_width]
